[telepathy-glib/master] tp_proxy_pending_call_v0_new: rename @interface to @iface

Simon McVittie simon.mcvittie at collabora.co.uk
Fri Nov 13 06:46:46 PST 2009


Same rationale as previous commit.
---
 telepathy-glib/proxy-methods.c  |    8 ++++----
 telepathy-glib/proxy-subclass.h |    2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/telepathy-glib/proxy-subclass.h b/telepathy-glib/proxy-subclass.h
index eb80927..b0f4a38 100644
--- a/telepathy-glib/proxy-subclass.h
+++ b/telepathy-glib/proxy-subclass.h
@@ -32,7 +32,7 @@ typedef void (*TpProxyInvokeFunc) (TpProxy *self,
     GObject *weak_object);
 
 TpProxyPendingCall *tp_proxy_pending_call_v0_new (TpProxy *self,
-    GQuark interface, const gchar *member, DBusGProxy *iface_proxy,
+    GQuark iface, const gchar *member, DBusGProxy *iface_proxy,
     TpProxyInvokeFunc invoke_callback,
     GCallback callback, gpointer user_data, GDestroyNotify destroy,
     GObject *weak_object, gboolean cancel_must_raise);
diff --git a/telepathy-glib/proxy-methods.c b/telepathy-glib/proxy-methods.c
index 011dcd8..cc48780 100644
--- a/telepathy-glib/proxy-methods.c
+++ b/telepathy-glib/proxy-methods.c
@@ -198,9 +198,9 @@ _tp_proxy_pending_call_dgproxy_destroy (DBusGProxy *iface_proxy,
 /**
  * tp_proxy_pending_call_v0_new:
  * @self: a proxy
  * @interface: a quark whose string value is the D-Bus interface
  * @member: the name of the method being called
- * @iface_proxy: the interface-specific #DBusGProxy for @interface
+ * @iface_proxy: the interface-specific #DBusGProxy for @iface
  * @invoke_callback: an implementation of #TpProxyInvokeFunc which will
  *  invoke @callback with appropriate arguments
  * @callback: a callback to be called when the call completes
@@ -241,7 +241,7 @@ _tp_proxy_pending_call_dgproxy_destroy (DBusGProxy *iface_proxy,
  */
 TpProxyPendingCall *
 tp_proxy_pending_call_v0_new (TpProxy *self,
-                              GQuark interface,
+                              GQuark iface,
                               const gchar *member,
                               DBusGProxy *iface_proxy,
                               TpProxyInvokeFunc invoke_callback,
@@ -259,7 +259,7 @@ tp_proxy_pending_call_v0_new (TpProxy *self,
   pc = g_slice_new0 (TpProxyPendingCall);
 
   MORE_DEBUG ("(proxy=%p, if=%s, meth=%s, ic=%p; cb=%p, ud=%p, dn=%p, wo=%p)"
-      " -> %p", self, g_quark_to_string (interface), member, invoke_callback,
+      " -> %p", self, g_quark_to_string (iface), member, invoke_callback,
       callback, user_data, destroy, weak_object, pc);
 
   pc->proxy = g_object_ref (self);
@@ -198,9 +198,9 @@ _tp_proxy_pending_call_dgproxy_destroy (DBusGProxy *iface_proxy,
  * tp_proxy_pending_call_v0_new:
  * @self: a proxy
- * @interface: a quark whose string value is the D-Bus interface
+ * @iface: a quark whose string value is the D-Bus interface
  * @member: the name of the method being called
-- 
1.5.6.5




More information about the telepathy-commits mailing list